@@ -31,4 +31,4 @@ read -p "Upload to Framagit and PyPI? (y/N) " confirm
 if [ ! "$confirm" = y ]; then "Abort"; exit 1; fi
 
 python3 -m twine upload dist/*-${version}*
-git push origin "$tagid"
+git push origin "$tagid" master
